@@ -23,11 +23,6 @@ require 'rubyforge'
 Echoe.silence { require 'rubygems/specification' }
 
 require "#{$HERE}/echoe/rubygems"
-begin
-  gem 'gemcutter'
-  require 'rubygems_plugin'
-rescue Gem::LoadError
-end
 
 begin; require 'rcov/rcovtask'; rescue LoadError; end
 begin; require 'load_multi_rails_rake_tasks'; rescue LoadError; end
@@ -153,7 +148,7 @@ class Echoe
   include Rake::DSL
 
   # user-configurable
-  attr_accessor :author, :changes, :clean_pattern, :description, :email, :runtime_dependencies, :development_dependencies, :need_tgz, :need_tar_gz, :need_gem, :need_zip, :rdoc_pattern, :project, :summary, :test_pattern, :spec_pattern, :url, :version, :docs_host, :rdoc_template, :manifest_name, :install_message, :extension_pattern, :private_key, :certificate_chain, :require_signed, :ruby_version, :platform, :ignore_pattern, :executable_pattern, :require_paths, :changelog, :rcov_options, :gemspec_format
+  attr_accessor :author, :changes, :clean_pattern, :description, :email, :runtime_dependencies, :development_dependencies, :need_tgz, :need_tar_gz, :need_gem, :need_zip, :rdoc_pattern, :project, :summary, :test_pattern, :spec_pattern, :url, :version, :docs_host, :rdoc_template, :manifest_name, :install_message, :extension_pattern, :private_key, :certificate_chain, :require_signed, :ruby_version, :platform, :ignore_pattern, :executable_pattern, :require_paths, :changelog, :rcov_options, :gemspec_format, :licenses
 
   # best left alone
   attr_accessor :name, :lib_files, :test_files, :bin_files, :spec, :rdoc_options, :include_gemspec, :include_rakefile, :gemspec_name, :retain_gemspec, :rakefile_name, :eval, :files, :changelog_patterns, :rubygems_version, :use_sudo, :gem_bin
@@ -168,6 +163,7 @@ class Echoe
     self.project = name.downcase
     self.changelog = "CHANGELOG"
     self.author = ""
+    self.licenses = []
     self.email = ""
     self.clean_pattern = ["pkg", "doc", 'build/*', '**/coverage', '**/*.o', '**/*.so', '**/*.a', '**/*.log', "{ext,lib}/*.{bundle,so,obj,pdb,lib,def,exp}", "ext/Makefile", "{ext,lib}/**/*.{bundle,so,obj,pdb,lib,def,exp}", "ext/**/Makefile", "pkg", "*.gem", ".config"]
     self.test_pattern = File.exist?("test/test_all.rb") ? "test/test_all.rb" : ['test/**/test_*.rb', 'test/**/*_test.rb']
@@ -199,7 +195,7 @@ class Echoe
     self.gemspec_format = :ruby
 
     title = (name.downcase == name ? name.capitalize : name)
-    self.rdoc_options = ['--line-numbers', '--inline-source', '--title', title]
+    self.rdoc_options = ['--line-numbers', '--title', title]
 
     readme = Dir['*'].detect { |filename| filename =~ /^readme/i }
     self.rdoc_options += ['--main', readme] if readme
@@ -349,6 +345,7 @@ private
       # s.specification_version = 3
       s.summary = summary
       s.author = Array(author).join(", ")
+      s.licenses = Array(licenses)
       s.email = email
       s.homepage = url
       s.rubyforge_project = project if project
@@ -498,8 +495,9 @@ private
       git_branch = nil
       if (File.exist?(".git"))
         git_branch = `git branch --no-color | egrep '^\\*' | awk '{print $2}'`.chomp
-        if (`git diff origin/#{git_branch}`).any?
+        if (diff = `git diff origin/#{git_branch}`).any?
           puts "You need to commit and push your changes first."
+          puts diff
           exit(1)
         end
       end
@@ -577,7 +575,7 @@ private
       elsif ENV['RDOC_TEMPLATE']
         rd.template = ENV['RDOC_TEMPLATE']
       elsif `allison --path`.any?
-        rd.template = `allison --path`.chomp
+        rd.template = `allison --path`.chomp + ".rb"
       end
     end
 
